@@ -24,7 +24,7 @@ if TYPE_CHECKING:  # bad import
     from functools import missing  # noqa: F401
 
 
-def a(f: Decimal, s: AnyStr) -> Sequence[AnyStr | Decimal]:
+def a[AnyStr: (bytes, str)](f: Decimal, s: AnyStr) -> Sequence[AnyStr | Decimal]:
     """
     Do.
 
